Variables, Expressions, and Statements
:::::::::::::::::::::::::::::::::::::::::::

.. toctree::
   :caption: Variables
   :maxdepth: 3

   values-and-types.rst
   variables-section.rst
   variable-names-keywords.rst
   statements.rst
   operators-and-operands.rst
   expressions.rst
   order-of-operations.rst
   modulus.rst
   string-operations.rst
   user-input.rst
   comments.rst
   mnemonic-names.rst
   debugging.rst
   glossary.rst
   Exercises.rst
   MixedupCode.rst
   WriteCode.rst
